﻿Import-Module FailoverClusters
Import-Module virtualmachinemanager

$CSVArray=@()
$Cluster=Get-SCVMHostCluster|Out-GridView -PassThru
$Hosts=Get-SCVMHostCluster -Name $Cluster|Get-SCVMHost
$CSVs=Get-ClusterSharedVolume -Cluster $Cluster.Name

foreach ($CSV in $CSVs){
    $CSVInfo=$CSV|Select -Property Name -ExpandProperty SharedVolumeInfo
    $OvercommitSpace=0
    $Overcommited="false"
        foreach($Hoster in $Hosts){
            $VMs=Get-SCVirtualMachine -VMHost $Hoster|Where{$_.Location.Substring(0,25) -eq $CSVInfo.FriendlyVolumeName}
                foreach($VM in $VMs){
                    $VHDs=Get-SCVirtualHardDisk -VM $VM
                    foreach($VHD in $VHDs){
                        $OvercommitSpace = $OvercommitSpace + $VHD.MaximumSize
                    }
                }
        }
        if($CSVInfo.Partition.Size -le $OvercommitSpace){
            $Overcommited = "true"
        }
        $Info = New-Object PSObject -Property @{
            Name=$CSV.Name
            Path=$CSVInfo.FriendlyVolumeName
            Size=$CSVInfo.Partition.Size
            FreeSpace=$CSVInfo.Partition.FreeSpace
            UsedSpace=$CSVInfo.Partition.UsedSpace
            Overcommited=$Overcommited
            Overcommitment=$OvercommitSpace
            OvercommitedPercentage=((($OvercommitSpace/1024/1024/1024)/($CSVInfo.Partition.Size/1024/1024/1024))*100)-100
        }
        $CSVArray += $Info
}

$CSVArray|ft -auto Name,Path,@{Label="Size(GB)";Expression={"{0:N2}" -f ($_.Size/1024/1024/1024)}},@{Label="Free(GB)";Expression={"{0:N2}" -f ($_.FreeSpace/1024/1024/1024)}},@{Label="Used(GB)";Expression={"{0:N2}" -f ($_.UsedSpace/1024/1024/1024)}},Overcommited,@{Label="Effective Used(GB)";Expression={"{0:N2}" -f ($_.Overcommitment/1024/1024/1024)}},@{Label="Overcommited %";Expression={"{0:N2}" -f ($_.OvercommitedPercentage)}}